#!/bin/sh

#Conf dir/file definition
PKG_FOLDER="/var/packages/CloudSync"
PKG_DIR="$PKG_FOLDER/target"
CONF_DIR="${PKG_FOLDER}/etc"
CONF_PATH="${CONF_DIR}/setting.conf"

# daemons
SYNCD_PATH="${PKG_DIR}/sbin/syno-cloud-syncd"
STARTER_PATH="${PKG_DIR}/bin/cloud-sync-starter"

# pid files
UPDATER_PID_FILE="/usr/syno/etc/packages/CloudSync/cloud_sync_upgrading_mark"
SYNCD_PID_FILE="/var/run/syno-cloud-syncd.pid"

#CSTN_SET_VAL_TOOL="/usr/syno/bin/synosetkeyvalue"


#Global variables
CLOUD_SYNC_ENABLE="0"
CLOUD_SYNC_DBG_LEVEL=0

debug_msg() {
	#echo "CS: $1";
	if [ 2 -le $CLOUD_SYNC_DBG_LEVEL ]; then
		logger -p 0 "CS: [start.sh]: $1"
	fi
}

info_msg() {
	#echo "CS: $1";
	if [ 1 -le $CLOUD_SYNC_DBG_LEVEL ]; then
		logger -p 0 "CS: [start.sh]: $1"
	fi
}

err_msg() {
	if [ 0 -le $CLOUD_SYNC_DBG_LEVEL ]; then
		logger -p 0 "CS: [start.sh]: $1"
	fi
}

get_conf() {
	if [ -f "${CONF_PATH}" ]; then
	    	CLOUD_SYNC_ENABLE=`/bin/get_key_value ${CONF_PATH} cstn_enable`
	else
		err_msg "Cloud sync setting config does not exist!";
		exit 1;
	fi
}

is_daemon_alive() {
    if [ -f "$1" ]; then
		local pid=`cat "$1"`
		
		kill -0 $pid
		if [ "0" = "$?" ]; then
	    	echo "$pid";
			return 1;
		else
			echo "0";
			return 0;
		fi
    fi
	
	echo "0";
	return 0;
}

stop_daemon() {
	# stop all daemons
	${STARTER_PATH} --stop

	return 0;
}

get_homes_vol() {
	local homes_vol=`synoshare --get homes | grep "Path ......." | sed -e 's/^.*\[\(.*\)\/.*\]/\1/g'`;
	
	if [ "x" = "x${homes_vol}" ]; then
		err_msg "Fail to get homes volume!";
		exit 1;
	fi

	echo "${homes_vol}"
	return 0;
}


prepare_env() {
	return 0;
}

remove_env() {
	return 0;
}

start_daemon() {
	# run cloud-sync-starter
	${STARTER_PATH} --start &
	return 0;
}

case $1 in
    start)
		err_msg "Cloud sync start..."
		start_daemon;
		;;

    stop)
		err_msg "Cloud sync stop..."
		stop_daemon
   		;;

    restart)
		debug_msg "Cloud sync restart..."
		$0 stop;
		$0 start;
    	;;
    *)
		echo "Usage: $0 start|stop|restart"
    ;;
esac

